function [x,t] = ee(f, T, N, x0)
% EE  : Euler Explicite
% Entrées :
%   f   : fonction du type f(t, x) représentant l'EDO dx/dt = f(t, x)
%   T   : temps final
%   N   : nombre de pas de temps
%   x0  : condition initiale x(0) = x0
% Sorties :
%   x   : vecteur des solutions approximatives aux temps t
%   t   : vecteur des temps

x(1) = x0;          % Initialisation de la solution avec la condition initiale
dt = T / N;         % Calcul du pas de temps

for n = 1:N
    t(n) = (n - 1) * dt;                  % Calcul du temps courant
    x(n + 1) = x(n) + dt * f(t(n), x(n)); % Formule d'Euler explicite : x_{n+1} = x_n + dt * f(t_n, x_n)
end

t(N + 1) = T;       % Ajout du temps final dans le vecteur des temps

end
