clear all       % Efface toutes les variables en mémoire
clc             % Efface la fenêtre de commande
close all       % Ferme toutes les figures ouvertes

% Paramètres du problème
lambda = 10;    % Coefficient de décroissance
T = 10;         % Temps final
x0 = 1;         % Condition initiale
N = 100;        % Nombre de pas de temps

% Définition de la fonction f(t,x) = -lambda * x
f = @(t,x)(-lambda*x);

% Dérivée partielle de f par rapport à x (utile pour le schéma implicite)
df = @(t,x)(-lambda); 

% Intégration par le schéma d’Euler explicite
[x, t] = ee(f, T, N, x0);

% Intégration par le schéma d’Euler implicite
[xi, ti] = ei(f, df, T, N, x0);

% Calcul de la solution exacte pour comparaison
tex = 0:0.01:T;
xex = x0 * exp(-lambda * tex); % Solution analytique : x(t) = x0 * exp(-lambda * t)

% Affichage des résultats
figure(1)
plot(t, x, ti, xi, tex, xex, 'LineWidth', 3); % Tracé des solutions
legend('NUMERICAL SOLUTION BY EE SCHEME', ...
       'NUMERICAL SOLUTION BY EI SCHEME', ...
       'EXACT SOLUTION');

% Étude de l’erreur en fonction du raffinement du pas de temps (ordre de convergence)
NN = 100:10:1000; % Différents nombres de pas de temps
for i = 1:length(NN)
    N = NN(i); 
    
    % Euler explicite
    [x, t] = ee(f, T, N, x0);
    E(i) = max(abs(x - x0 * exp(-lambda * t))); % Erreur maximale

    % Euler implicite
    [xi, ti] = ei(f, df, T, N, x0);
    Ei(i) = max(abs(xi - x0 * exp(-lambda * ti))); % Erreur maximale
end

% Tracés des erreurs (log-log pour estimer l'ordre)
figure(2)
subplot(211)
plot(log(NN), log(E), log(NN), log(Ei), 'LineWidth', 3)
legend('EE', 'EI')
title('Log-Log Plot of Error')

subplot(212)
plot(NN, E, NN, Ei, 'LineWidth', 3)
legend('EE', 'EI')
title('Error vs N')
